import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_story/src/models/story.dart';
import 'package:ocg_story/src/repository/story.dart';

///
/// Events
///
abstract class StoryListEvent {}

class StoryListRefreshEvent extends StoryListEvent {}

abstract class StoryListState {}

class StoryListIdleState extends StoryListState {}

class StoryListLoadingState extends StoryListState {}

class StoryListLoadedState extends StoryListState {
  final Map<String, List<Story>> stories;

  StoryListLoadedState(this.stories);
}

class StoryListErrorState extends StoryListState {
  final String error;

  StoryListErrorState(this.error);
}

class StoryListBloc extends Bloc<StoryListEvent, StoryListState> {
  final StoryRepository storyRepository;
  StoryListBloc(this.storyRepository) : super(StoryListIdleState());

  @override
  Stream<StoryListState> mapEventToState(StoryListEvent event) async* {
    if (event is StoryListRefreshEvent) {
      yield StoryListLoadingState();
      AppResponse<Map<String, List<Story>>> storiesResponse =
          await storyRepository.getStories();
      if (storiesResponse.isSuccess) {
        yield StoryListLoadedState(storiesResponse.data);
      } else {
        yield StoryListErrorState(storiesResponse.error);
      }
    }
  }
}
