import 'package:json_annotation/json_annotation.dart';

class StoryType {
  static String get image => "image";
  static String get video => "video";
  static String get quiz => "quiz";
  static String get quizList => "quizList";
}

@JsonSerializable(explicitToJson: true)
class Story {
  final String id;
  final String thumbnail;
  final StoryUser user;
  final DateTime recordedAt;
  final StoryBackground background;
  final StoryData data;
  final List<String> seenBy;

  Story(this.id, this.thumbnail, this.user, this.recordedAt, this.background,
      this.data, this.seenBy);

  Story.named(
      {this.id,
      this.thumbnail,
      this.user,
      this.recordedAt,
      this.background,
      this.data,
      this.seenBy});

  copyWith({String id, data, recordedAt, thumbnail, user, seenBy}) {
    return Story.named(
        id: id ?? this.id,
        data: data ?? this.data,
        background: background ?? this.background,
        recordedAt: recordedAt ?? this.recordedAt,
        thumbnail: thumbnail ?? this.thumbnail,
        user: user ?? this.user,
        seenBy: seenBy ?? this.seenBy);
  }
}

@JsonSerializable(explicitToJson: true)
class StoryUser {
  final String id;
  final String name;
  final String profilePic;

  StoryUser(this.id, this.name, this.profilePic);
  StoryUser.named({this.id, this.name, this.profilePic});
}

@JsonSerializable(explicitToJson: true)
abstract class StoryBackground {
  final String type;

  StoryBackground(
    this.type,
  );
}

@JsonSerializable(explicitToJson: true)
class StoryVideo extends StoryBackground {
  final String url;
  final String thumbnail;

  StoryVideo(this.url, this.thumbnail) : super(StoryType.video);

  StoryVideo.named({this.url, this.thumbnail}) : super(StoryType.video);
}

@JsonSerializable(explicitToJson: true)
class StoryImage extends StoryBackground {
  final String url;

  StoryImage(this.url) : super(StoryType.image);

  StoryImage.named({this.url}) : super(StoryType.image);
}

@JsonSerializable(explicitToJson: true)
abstract class StoryData {
  final String type;

  StoryData(
    this.type,
  );
}

@JsonSerializable(explicitToJson: true)
class StoryQuiz extends StoryData {
  final String id;
  final String storyId;
  final String question;
  final List<String> answers;
  final int selectedAnswer;

  StoryQuiz(
      this.id, this.storyId, this.question, this.answers, this.selectedAnswer)
      : super(StoryType.quiz);

  StoryQuiz.named(
      {this.id, this.storyId, this.question, this.answers, this.selectedAnswer})
      : super(StoryType.quiz);

  static StoryQuiz get empty => StoryQuiz.named(
      answers: [null, null, null], id: null, question: null, storyId: null);

  StoryQuiz copyWith(
      {String id,
      String storyId,
      String question,
      List<String> answers,
      int selectedAnswer}) {
    return StoryQuiz.named(
        id: id ?? this.id,
        storyId: storyId ?? this.storyId,
        answers: answers ?? this.answers,
        question: question ?? this.question,
        selectedAnswer: selectedAnswer ?? this.selectedAnswer);
  }
}

class StoryQuizList extends StoryData {
  final List<StoryQuiz> quizzes;
  StoryQuizList(this.quizzes) : super(StoryType.quizList);
}
