import 'dart:async';

import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_story/src/models/story.dart';
import 'package:uuid/uuid.dart';

abstract class StoryRepository {
  Future<AppResponse<Story>> createStory(Story story);
  Future<AppResponse<Map<String, List<Story>>>> getStories();
}

class StoryTestRepository extends StoryRepository {
  final List<Story> _stories;

  StoryTestRepository()
      : _stories = [
          Story.named(
              id: "122",
              background: StoryVideo.named(
                url:
                    "https://firebasestorage.googleapis.com/v0/b/fairpriceit-a7636.appspot.com/o/1883334546.mp4?alt=media&token=48e21ccd-ad90-478f-b979-f8280684e0f8",
                thumbnail:
                    "https://images.pexels.com/photos/3076511/pexels-photo-3076511.jpeg?auto=compress&cs=tinysrgb&dpr=2&h=750&w=1260",
              ),
              thumbnail:
                  "https://images.pexels.com/photos/3076511/pexels-photo-3076511.jpeg?auto=compress&cs=tinysrgb&dpr=2&h=750&w=1260",
              user: StoryUser.named(
                  id: "1",
                  name: "Osi Peters",
                  profilePic:
                      "https://specials-images.forbesimg.com/imageserve/1219616367/960x0.jpg?fit=scale"),
              recordedAt: DateTime.now(),
              data: StoryQuiz.named(
                  question:
                      "WHICH NIKE DUNK COLORWAY ORIGINATED AS A CO.JP RELEASE?",
                  answers: ["STRANGE LOVE", "PLUM", "TRUCK IT"],
                  selectedAnswer: 0,
                  id: "1",
                  storyId: "122")),
        ];

  @override
  Future<AppResponse<Story>> createStory(Story story) async {
    await Future.delayed(Duration(seconds: 1));
    String id = Uuid().v4();
    story = story.copyWith(recordedAt: DateTime.now(), user: testUser, id: id);
    _stories.add(story);
    return AppResponse.named(data: story);
  }

  @override
  Future<AppResponse<Map<String, List<Story>>>> getStories() async {
    return AppResponse.named(
        data: _stories.length == 0 ? {} : {testUser.id: _stories});
  }

  StoryUser get testUser => StoryUser.named(
      id: "1",
      name: "Osi Peters",
      profilePic:
          "https://specials-images.forbesimg.com/imageserve/1219616367/960x0.jpg?fit=scale");
}
