import 'dart:io';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_story/src/models/basic.dart';
import 'package:ocg_story/src/widgets/smiley_add_widget.dart';
import 'package:ocg_story/src/widgets/story_create_widget.dart';
import 'package:ocg_story/src/widgets/text_add_widget.dart';

class StoryImageCreateScreen extends StatefulWidget {
  final ImageData imageData;

  const StoryImageCreateScreen({Key key, @required this.imageData})
      : super(key: key);
  @override
  State<StatefulWidget> createState() => _StoryImageCreateScreenState();
}

class _StoryImageCreateScreenState extends State<StoryImageCreateScreen> {
  List<Basic> children = [];
  final GlobalKey<ScaffoldState> key = GlobalKey<ScaffoldState>();
  List<Widget> stackChildren = [];
  StoryCreateController controller;
  @override
  void initState() {
    super.initState();
    children.add(widget.imageData);
    WidgetsBinding.instance.addPostFrameCallback((_) {
      offset = Offset(MediaQuery.of(context).size.width / 2 - 32.0,
          MediaQuery.of(context).size.height - 150);
      setState(() {
        stackChildren.add(
          StoryCreateWidget(
            children: children,
            deleteOffset: offset,
            onCompleted: (controller) {
              this.controller = controller;
            },
          ),
        );
        stackChildren.add(buildOptionsScreen());
      });
    });
  }

  Offset offset;
  bool adding = false;
  @override
  Widget build(BuildContext context) {
    if (offset == null) {
      return Container();
    }
    List<Widget> widgets = [];
    widgets.addAll(stackChildren);
    if (!adding)
      widgets.add(Positioned(
          top: offset.dy,
          left: offset.dx,
          child: FloatingActionButton(
            onPressed: () {},
            child: Icon(
              Icons.delete_forever,
              color: Colors.black,
            ),
            backgroundColor: Colors.white,
          )));
    return AnnotatedRegion<SystemUiOverlayStyle>(
      value: SystemUiOverlayStyle.light,
      child: Scaffold(
        key: key,
        backgroundColor: Colors.transparent,
        body: SafeArea(
          child: Stack(
            fit: StackFit.expand,
            children: widgets,
          ),
        ),
      ),
    );
  }

  Widget buildButton(IconData iconData, Function onPressed) {
    return Padding(
      padding: const EdgeInsets.all(6.0),
      child: IconButton(
        onPressed: onPressed,
        color: Colors.black26,
        icon: Icon(
          iconData,
          color: Colors.white,
        ),
      ),
    );
  }

  Widget buildOptionsScreen() {
    return Container(
        width: MediaQuery.of(context).size.width,
        height: MediaQuery.of(context).size.height,
        child: Column(
            crossAxisAlignment: CrossAxisAlignment.stretch,
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: <Widget>[
              Container(
                padding: EdgeInsets.all(4),
                decoration: BoxDecoration(color: Colors.black12, boxShadow: [
                  BoxShadow(
                      color: Colors.black12, blurRadius: 12, spreadRadius: 1)
                ]),
                child: Row(
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: <Widget>[
                    IconButton(
                        icon: Icon(
                          Icons.clear,
                          color: Colors.white,
                        ),
                        onPressed: () {
                          Navigator.of(context).maybePop();
                        }),
                    Row(
                      mainAxisSize: MainAxisSize.min,
                      children: <Widget>[
                        buildButton(Icons.text_fields, () {
                          setState(() {
                            adding = true;
                            stackChildren.removeLast();
                            stackChildren.add(TextAddWidget(
                              onSelected: onSelected,
                            ));
                          });
                        }),
                        buildButton(Icons.tag_faces, () {
                          setState(() {
                            adding = true;
                            stackChildren.removeLast();
                            stackChildren.add(SmileyAddWidget(
                              onSelected: onSelected,
                            ));
                          });
                        }),
                      ],
                    )
                  ],
                ),
              ),
              Padding(
                  padding: const EdgeInsets.all(8.0),
                  child: Center(
                    child: Row(
                      crossAxisAlignment: CrossAxisAlignment.baseline,
                      textBaseline: TextBaseline.alphabetic,
                      mainAxisAlignment: MainAxisAlignment.spaceBetween,
                      children: <Widget>[
                        Container(),
                        RaisedButton(
                          padding: EdgeInsets.all(16.0),
                          shape: RoundedRectangleBorder(
                              borderRadius: BorderRadius.circular(8.0)),
                          onPressed: () async {
                            if (controller != null) {
                              AppResponse<File> response =
                                  await controller.createStory();
                              debugPrint("Create Response ${response.error}");
                              if (response.isSuccess) {
                                Navigator.of(context).pop(ImageData.named(
                                    imagePath: response.data.path));
                              } else {
                                key.currentState.showSnackBar(SnackBar(
                                    content: Text("${response.error}")));
                              }
                            }
                          },
                          child: Row(
                            mainAxisSize: MainAxisSize.min,
                            children: <Widget>[
                              Padding(
                                padding: const EdgeInsets.only(right: 8.0),
                                child: Text(
                                  "Your story",
                                  style: TextStyle(
                                      fontSize: 15.0,
                                      color: Colors.black,
                                      fontWeight: FontWeight.w500),
                                ),
                              ),
                              Icon(Icons.send)
                            ],
                          ),
                          color: Colors.white,
                        ),
                      ],
                    ),
                  ))
            ]));
  }

  void showLoadingDialog() {
    showDialog(
        context: context,
        builder: (context) {
          return AlertDialog(
            content: Container(
              height: 75.0,
              child: Row(
                children: <Widget>[
                  CircularProgressIndicator(),
                  Expanded(
                      child: Padding(
                    padding: const EdgeInsets.all(8.0),
                    child: Text("This may take some time"),
                  ))
                ],
              ),
            ),
          );
        },
        barrierDismissible: false);
  }

  void onSelected(Basic basic) {
    setState(() {
      adding = false;
      if (basic != null) children.add(basic);
      stackChildren.clear();
      stackChildren.add(
        StoryCreateWidget(
          deleteOffset: offset,
          children: children,
          onCompleted: (controller) {
            this.controller = controller;
          },
        ),
      );
      stackChildren.add(buildOptionsScreen());
    });
  }

  void pushBack() {}
}
