import 'dart:io';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:ocg_story/src/models/basic.dart';
import 'package:video_player/video_player.dart';

class StoryVideoCreateScreen extends StatefulWidget {
  final VideoData videoData;

  const StoryVideoCreateScreen({
    Key key,
    @required this.videoData,
  }) : super(key: key);
  @override
  _StoryVideoCreateScreenState createState() => _StoryVideoCreateScreenState();
}

class _StoryVideoCreateScreenState extends State<StoryVideoCreateScreen> {
  VideoPlayerController videoPlayerController;

  @override
  void initState() {
    super.initState();
    videoPlayerController =
        VideoPlayerController.file(File(widget.videoData.videoPath));
  }

  @override
  Widget build(BuildContext context) {
    return AnnotatedRegion<SystemUiOverlayStyle>(
      value: SystemUiOverlayStyle.light,
      child: Scaffold(
        backgroundColor: Colors.black,
        appBar: AppBar(
          brightness: Brightness.dark,
          backgroundColor: Colors.transparent,
          iconTheme: IconThemeData(color: Colors.white),
        ),
        body: SafeArea(
          child: Center(
            child: Stack(
              alignment: Alignment.center,
              children: <Widget>[
                FutureBuilder(
                  future: videoPlayerController.initialize()
                    ..then((value) {
                      videoPlayerController.play();
                      videoPlayerController.setLooping(true);
                    }),
                  builder: (context, snapshot) {
                    if (snapshot.connectionState == ConnectionState.done) {
                      return AspectRatio(
                        aspectRatio: videoPlayerController.value.aspectRatio,
                        child: VideoPlayer(videoPlayerController),
                      );
                    } else {
                      return Center(child: CircularProgressIndicator());
                    }
                  },
                ),
              ],
            ),
          ),
        ),
        floatingActionButton: RaisedButton(
          padding: EdgeInsets.all(16.0),
          shape:
              RoundedRectangleBorder(borderRadius: BorderRadius.circular(8.0)),
          onPressed: () async {
            Navigator.of(context).pop(widget.videoData);
          },
          child: Row(
            mainAxisSize: MainAxisSize.min,
            children: <Widget>[
              Padding(
                padding: const EdgeInsets.only(right: 8.0),
                child: Text(
                  "Your story",
                  style: TextStyle(
                      fontSize: 15.0,
                      color: Colors.black,
                      fontWeight: FontWeight.w500),
                ),
              ),
              Icon(Icons.send)
            ],
          ),
          color: Colors.white,
        ),
      ),
    );
  }

  @override
  void dispose() {
    videoPlayerController.dispose();
    super.dispose();
  }
}
